==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val hyperVFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .hyperVFabricArmId(hyperVFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var hyperVFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("vifbpchdaxtntunj")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("fjxcimyknqsaxlxn")
    public suspend fun hyperVFabricArmId(`value`: Output<String>) {
        this.hyperVFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("gymktfqajdavlywc")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("wydtplsuqaugdktm")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("emkowpjvhqkbcdsd")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("xonfsywghuvpesak")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("vtowgnhbgcorxcxg")
    public suspend fun hyperVFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hyperVFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("isgomqlkegftyvrf")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("doukpdndptpimvrk")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("swafpkkhkknfwthg")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    internal fun build(): HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            hyperVFabricArmId = hyperVFabricArmId ?: throw PulumiNullFieldException("hyperVFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val hyperVFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .hyperVFabricArmId(hyperVFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var hyperVFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("btlkgnottfnpkeei")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("guavnpgianqfjgyy")
    public suspend fun hyperVFabricArmId(`value`: Output<String>) {
        this.hyperVFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("kmghmxvjahxylntg")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("exqhnbisnxwgqjmj")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("ycendgrvrewawbat")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("muylyfsrepkkeuay")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("lvkgqwfyhhhpiqgc")
    public suspend fun hyperVFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hyperVFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("apttglqoyqtvcatf")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("xhewuvyqsxsdoxiu")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("sisoxtoaqepgepvc")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    internal fun build(): HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            hyperVFabricArmId = hyperVFabricArmId ?: throw PulumiNullFieldException("hyperVFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
        )
}
